History
-------

.. to_doc

-------------------
24.0.3 (2024-06-28)
-------------------


=========
Bug fixes
=========

* Add ``hgweb_repo_prefix`` attribute to ``TestToolShedConfig`` by `@nsoranzo <https://github.com/nsoranzo>`_ in `#18268 <https://github.com/galaxyproject/galaxy/pull/18268>`_
* Fix tool_shed package unit tests by `@mvdbeek <https://github.com/mvdbeek>`_ in `#18327 <https://github.com/galaxyproject/galaxy/pull/18327>`_
* Fix one more tool shed unit test by `@mvdbeek <https://github.com/mvdbeek>`_ in `#18328 <https://github.com/galaxyproject/galaxy/pull/18328>`_

-------------------
24.0.2 (2024-05-07)
-------------------

No recorded changes since last release

-------------------
24.0.1 (2024-05-02)
-------------------

No recorded changes since last release

-------------------
24.0.0 (2024-04-02)
-------------------


=========
Bug fixes
=========

* Reload built-in converters on toolbox reload by `@bernt-matthias <https://github.com/bernt-matthias>`_ in `#17209 <https://github.com/galaxyproject/galaxy/pull/17209>`_

============
Enhancements
============

* Enable ``warn_unreachable`` mypy option by `@mvdbeek <https://github.com/mvdbeek>`_ in `#17365 <https://github.com/galaxyproject/galaxy/pull/17365>`_

-------------------
23.2.1 (2024-02-21)
-------------------

First release
